==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/LONGDESCRIPTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour LONGDESCRIPTIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LONGDESCRIPTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LONGDESCRIPTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LONGDESCRIPTIONID_Type", propOrder = {
    "longdescriptioncode",
    "entityid",
    "languageid"
})
public class LONGDESCRIPTIONID_Type {

    @XmlElement(name = "LONGDESCRIPTIONCODE", required = true)
    protected String longdescriptioncode;
    @XmlElement(name = "ENTITYID", required = true)
    protected ENTITYID_Type entityid;
    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;

    /**
     * Obtient la valeur de la propriété longdescriptioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLONGDESCRIPTIONCODE() {
        return longdescriptioncode;
    }

    /**
     * Définit la valeur de la propriété longdescriptioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLONGDESCRIPTIONCODE(String value) {
        this.longdescriptioncode = value;
    }

    /**
     * Obtient la valeur de la propriété entityid.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Définit la valeur de la propriété entityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

    /**
     * Obtient la valeur de la propriété languageid.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Définit la valeur de la propriété languageid.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/LONGDESCRIPTIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LONGDESCRIPTIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LONGDESCRIPTIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LONGDESCRIPTIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LANGUAGEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LONGDESCRIPTIONID_Type", propOrder = {
    "longdescriptioncode",
    "entityid",
    "languageid"
})
public class LONGDESCRIPTIONID_Type {

    @XmlElement(name = "LONGDESCRIPTIONCODE", required = true)
    protected String longdescriptioncode;
    @XmlElement(name = "ENTITYID", required = true)
    protected ENTITYID_Type entityid;
    @XmlElement(name = "LANGUAGEID", required = true)
    protected LANGUAGEID_Type languageid;

    /**
     * Gets the value of the longdescriptioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLONGDESCRIPTIONCODE() {
        return longdescriptioncode;
    }

    /**
     * Sets the value of the longdescriptioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLONGDESCRIPTIONCODE(String value) {
        this.longdescriptioncode = value;
    }

    /**
     * Gets the value of the entityid property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYID_Type }
     *     
     */
    public ENTITYID_Type getENTITYID() {
        return entityid;
    }

    /**
     * Sets the value of the entityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYID_Type }
     *     
     */
    public void setENTITYID(ENTITYID_Type value) {
        this.entityid = value;
    }

    /**
     * Gets the value of the languageid property.
     * 
     * @return
     *     possible object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public LANGUAGEID_Type getLANGUAGEID() {
        return languageid;
    }

    /**
     * Sets the value of the languageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LANGUAGEID_Type }
     *     
     */
    public void setLANGUAGEID(LANGUAGEID_Type value) {
        this.languageid = value;
    }

}
